==> winnie-0.1.46.tgz: package/text-number-field.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var BoxField = require('kenga/box-field');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);
var BoxField__default = /*#__PURE__*/_interopDefaultLegacy(BoxField);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default['default'](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default['default'](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default['default'](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var TextNumberField = /*#__PURE__*/function (_BoxField) {
  _inherits__default['default'](TextNumberField, _BoxField);

  var _super = _createSuper(TextNumberField);

  function TextNumberField(text, box, shell) {
    var _this;

    _classCallCheck__default['default'](this, TextNumberField);

    if (arguments.length < 1) text = '';

    if (!box) {
      box = document.createElement('input');
      box.type = 'text';
    }

    if (!shell) {
      shell = box;
    }

    box.value = text;
    _this = _super.call(this, box, shell);

    var self = _assertThisInitialized__default['default'](_this);

    var value = null;

    function textChanged() {
      var oldValue = value; // @see set value

      value = box.value === '' ? null : box.type === 'number' ? +box.value : box.value;
      self.fireValueChanged(oldValue);
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'textChanged', {
      enumerable: false,
      get: function get() {
        return textChanged;
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'text', {
      get: function get() {
        return box.value;
      },
      set: function set(aValue) {
        if (box.value !== aValue) {
          box.value = aValue;
          textChanged();
        }
      }
    });
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'value', {
      get: function get() {
        return value;
      },
      set: function set(aValue) {
        var oldValue = value;
        value = aValue !== undefined ? aValue : null; // @see textChanged

        box.type = typeof value === 'number' ? 'number' : 'text';
        /**
         * Warning! Don't change as `item.value.src` because of auto normalization of URI with access to .src property.
         * Some environments do it as their local path + the value of `src` attribute and this ends up with something meaningless for runtime.
         * For example: file:///C:/Users/<user>/AppData/Local/atom/app-1.58.0/resources/app.asar/static/assets/icons/some-icon.svg instead of assets/icons/some-icon.svg .
         * @see render.js
         */

        box.value = value && value.src && value.getAttribute ? value.getAttribute('src') : value;
        self.fireValueChanged(oldValue);
      }
    });
    return _this;
  }

  return TextNumberField;
}(BoxField__default['default']);

module.exports = TextNumberField;

==> winnie-0.1.55.tgz: package/text-number-field.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var BoxField = require('kenga/box-field');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);
var BoxField__default = /*#__PURE__*/_interopDefaultLegacy(BoxField);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default["default"](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default["default"](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default["default"](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var TextNumberField = /*#__PURE__*/function (_BoxField) {
  _inherits__default["default"](TextNumberField, _BoxField);

  var _super = _createSuper(TextNumberField);

  function TextNumberField(text, box, shell) {
    var _this;

    _classCallCheck__default["default"](this, TextNumberField);

    if (arguments.length < 1) text = '';

    if (!box) {
      box = document.createElement('input');
      box.type = 'text';
    }

    if (!shell) {
      shell = box;
    }

    box.value = text;
    _this = _super.call(this, box, shell);

    var self = _assertThisInitialized__default["default"](_this);

    var value = null;

    function textChanged() {
      var oldValue = value; // @see set value

      value = box.value === '' ? null : box.type === 'number' ? +box.value : box.value;
      self.fireValueChanged(oldValue);
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'textChanged', {
      enumerable: false,
      get: function get() {
        return textChanged;
      }
    });
    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'text', {
      get: function get() {
        return box.value;
      },
      set: function set(aValue) {
        if (box.value !== aValue) {
          box.value = aValue;
          textChanged();
        }
      }
    });
    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'value', {
      get: function get() {
        return value;
      },
      set: function set(aValue) {
        var oldValue = value;
        value = aValue !== undefined ? aValue : null; // @see textChanged

        box.type = typeof value === 'number' ? 'number' : 'text';
        /**
         * Warning! Don't change as `item.value.src` because of auto normalization of URI with access to .src property.
         * Some environments do it as their local path + the value of `src` attribute and this ends up with something meaningless for runtime.
         * For example: file:///C:/Users/<user>/AppData/Local/atom/app-1.58.0/resources/app.asar/static/assets/icons/some-icon.svg instead of assets/icons/some-icon.svg .
         * @see render.js
         */

        box.value = value && value.src && value.getAttribute ? value.getAttribute('src') : value;
        self.fireValueChanged(oldValue);
      }
    });
    return _this;
  }

  return TextNumberField;
}(BoxField__default["default"]);

module.exports = TextNumberField;
